PyXMake Developer Guide: PyXMake.VTL.stm_make.Clean Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | List of all members
PyXMake.VTL.stm_make.Clean Class Reference

Add PyXMake source folder to system path (if not already present). More...

Inheritance diagram for PyXMake.VTL.stm_make.Clean:

## Public Member Functions
| run (self)

## Detailed Description

Add PyXMake source folder to system path (if not already present).

Allows usage as a plugin.

    Little clean extension: Cleans up a non-empty build directory.

Definition at line 54 of file stm_make.py.

## Member Function Documentation

## ◆ run()

PyXMake.VTL.stm_make.Clean.run | ( |  | self | ) |

    Delete all redundant folders and directories. Ignore read-only GIT repositories

    @author: garb_ma

Definition at line 58 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py